Proxy server connection handling and upstream proxy configuration.
Structs
- Accept
Options - Options returned when accepting a connection.
- Connect
Context - Context passed to a connect handler when a client connects to the powhttp proxy server.
- Http
Connect Request - Http
Direct Request - Http
Proxy Request - Process
Info - Information about the process that initiated the connection.
- Proxy
- An upstream proxy to route connections through.
- Socks4
Request - Target
Address - A host–port pair identifying the target server.
Enums
- Connect
Request - The protocol-specific request that initiated the proxy connection.
- Connect
Result - The result returned by a connect handler to accept or reject the connection.
- Proxy
Type - Upstream proxy protocol.