pub struct OverviewField { /* private fields */ }Expand description
A single computed field displayed in the Overview section of the Inspector.
The handler receives a SingleEntryContext and returns an optional string
value to display. Return None to hide the field for that entry.
use powhttp_sdk::{OverviewField, ExtensionHandle, SingleEntryContext, Error};
let field = OverviewField::new(
"content-length",
"Content Length",
async |ctx: SingleEntryContext, handle: ExtensionHandle| {
let entry = handle.get_session_entry(ctx.session_id, ctx.entry_id).await?;
let size = entry
.and_then(|entry| entry.response)
.and_then(|res| res.body_size)
.map(|size| size.to_string());
Ok(size)
},
);Implementations