Module proxy_server

Module proxy_server 

Proxy server connection handling and upstream proxy configuration.

Structs

AcceptOptions
Options returned when accepting a connection.
ConnectContext
Context passed to a connect handler when a client connects to the powhttp proxy server.
HttpConnectRequest
HttpDirectRequest
HttpProxyRequest
ProcessInfo
Information about the process that initiated the connection.
Proxy
An upstream proxy to route connections through.
Socks4Request
TargetAddress
A host–port pair identifying the target server.

Enums

ConnectRequest
The protocol-specific request that initiated the proxy connection.
ConnectResult
The result returned by a connect handler to accept or reject the connection.
ProxyType
Upstream proxy protocol.